'use strict';
import { GameDeckMode } from '../../common/utils/const/game-deck-mode-enum';
import { PhaserScene } from '../../common/utils/const/phaser-scene-enum';
import Phaser from 'phaser';

export default class MainMenuScene extends Phaser.Scene {

  constructor(menuEventListener) {
    super({ key: PhaserScene.MAIN_MENU, active: false });
    this.menuEventListener = menuEventListener;

    this.username = '';
    this.previousMenu = null;
  }

  preload() {
    console.log('Preload');
    this.load.image('game-cover', '../../assets/twelveHeroes_cover.png');
    this.load.html('main-menu', '../../assets/html/main-menu.html');
  }

  create() {
    console.log('create');
    let background = this.add.image(0, 0, 'game-cover');
    background.setOrigin(0, 0);

    // Add main-menu HTML
    let element = this.add.dom(400, 100).createFromCache('main-menu');

    // Menu blocks
    let loginHtmlDiv = element.getChildByID('login');
    let onlineRoomHtmlDiv = element.getChildByID('online-room');
    let gameCreationHtmlDiv = element.getChildByID('game-creation');

    // Login block buttons
    let connectButton = element.getChildByName('loginButton');
    let username = element.getChildByName('username');
    let connectionStatus = element.getChildByID('connectionStatus');
    let onlineGame = element.getChildByName('onlineGame');

    // Online room buttons
    let createOnlineGameButton = element.getChildByName('createOnlineGame');
    let joinOnlineGameButton = element.getChildByName('joinOnlineGame');
    let backToMainButton = element.getChildByName('backToMain');
    let createdOnlineGamesList = element.getChildByID('list-games');

    // Game creation buttons



    element.setPerspective(800);

    element.addListener('click');

    username.addEventListener("keyup", event => {
      if (connectButton.value === 'Connect') {
        if (event.key !== "Enter") return;
        connectButton.click();
        event.preventDefault();
      }
    });

    console.log(connectButton);
    connectButton.focus();
    element.on('click', function (event) {
      console.log(event);
      let eventName = event.target.name;
      switch (eventName) {
        case "loginButton":
          if (connectButton.value === 'Connect') {
            if (username.value !== '') {
              connectButton.disabled = true;
              connectionStatus.innerText = 'Connecting...';
              username.disabled = true;
              console.log(username.value);
              console.log(' log  :' + onlineGame.disabled);
              setTimeout(() => {
                connectionStatus.innerText = 'Connected as ' + username.value;
                this.username = username.value;
                onlineGame.disabled = false;
                connectButton.value = "Disconnect";

                connectButton.disabled = false;
              }, 1000);
            } else {
              connectionStatus.innerText = 'Not Connected : Enter Username';
            }
          } else {
            connectButton.disabled = true;
            connectionStatus.innerText = `Disconnecting ${this.username}...`;
            onlineGame.disabled = true;
            setTimeout(() => {
              connectionStatus.innerText = 'Not Connected';
              connectButton.value = "Connect";
              connectButton.disabled = false;
              username.value = '';
              this.username = username.value;

              username.disabled = false;
            }, 500);
          }
          break;
        case "onlineGame":
          loginHtmlDiv.style.display = 'none';
          onlineRoomHtmlDiv.style.display = 'block';

          break;
        case "backToMain":
          onlineRoomHtmlDiv.style.display = 'none';
          loginHtmlDiv.style.display = 'block';

          break;
        case "createOnlineGame":
          this.previousMenu = onlineRoomHtmlDiv;
          onlineRoomHtmlDiv.style.display = 'none';
          gameCreationHtmlDiv.style.display = 'block';
          break;
        case "backToPrev":
          this.previousMenu = null;
          gameCreationHtmlDiv.style.display = 'none';
          onlineRoomHtmlDiv.style.display = 'block';
          break;
        case "localGame":
          alert('Feature not implemented yet');
          break;

        default:
          break;
      }
    });

    this.tweens.add({
      targets: element,
      y: 215,
      duration: 2300,
      ease: 'Power3'
    });
    //this.add.dom



    // TODO : Display main menu
    // Create new scenes : Local player room / Multi player room
    // Pass to them the event listener
    // On local player room, user can enter player names, selected color, game deck mode & rules

    // FOR TESTING
    //this.fakeNewPnpGameSelected();
  }

  update() {

  }

  fakeNewPnpGameSelected() {
    setTimeout(() => {
      let pBlueName = prompt("Player blue name : ");
      let pRedName = prompt("Player red name : ");

      //let gameDeckModeOptions = Object.values(GameDeckMode);
      //let gameDeckMode = Utils.promptSelectAmongOptions("Select Deck Mode", gameDeckModeOptions);
      let gameDeckMode = "factions";
      let advancedRules = [];
      console.log("Calling listener");
      this.menuEventListener.onNewPnpGame(pBlueName, pRedName, gameDeckMode, advancedRules);
    }, 1000);
  }
}
